@@ -1,11 +1,13 @@
-from common import *
+import socket
 from random import randrange
 
+from common import *
+
 def rand_point():
     return Point(x=randrange(100), y=randrange(100))
 
 logger = Logger(also_print = True)
-parser = Parser(logger = logger)
+parser = Parser(logger)
 sock = socket.create_connection(SERVER_ADDR)
 f = sock.makefile("r+b", bufsize=0)
 
