@@ -1,5 +1,9 @@
 import sys
 sys.path.append("../..")
+
+import logging
+logging.basicConfig(level = logging.INFO)
+
 from protlib import *
 
 SERVER_ADDR = ("127.0.0.1", 12321)
