@@ -1,7 +1,9 @@
+import socket
+
 from common import *
 
 logger = Logger(also_print = True)
-parser = Parser(logger = logger)
+parser = Parser(logger)
 
 def rand_ssn():
     return [randrange(10) for i in range(9)]
